@@ -37,7 +37,7 @@ impl Topic {
             push_config: None,
             retain_acked_messages: false,
             retry_policy: None,
-            topic: format!("projects/{}/topics/{}", &self.client.project_id, &self.name),
+            topic: self.name.clone(),
         };
         let req = self.client.insert_authz_token(subs).await?;
         self.client.subscriber.create_subscription(req).await?;
